Overview
========

In this tutorial we will learn about how to build ADIOS2, and go through several tutorials explaining basic topics.

More specifically, we will go through the following examples:

1. :ref:`Download And Build <sec:tutorials_download_and_build>`
2. Basic tutorials:

   1. :ref:`Hello World <sec:tutorials_basics_hello_world>`
   2. :ref:`Array Variables <sec:tutorials_basics_variables>`
   3. :ref:`Attributes <sec:tutorials_basics_attributes>`
   4. :ref:`Operators <sec:tutorials_basics_operators>`
   5. :ref:`Steps <sec:tutorials_basics_steps>`

More advance tutorials that cover more information related to:

- Running ADIOS2 at scale (through files or streaming) with hands-on excercises: `Exascale I/O tutorial <http://tinyurl.com/adios-eied>`_
- Using ADIOS2 with Paraview, TAU, Catalyst, FIDES, VTK-M: `ADIOS2 tutorial at SC23 <http://tinyurl.com/adios-sc2023>`_
